@@ -1,6 +1,6 @@
 
 #include "comb/binary-debruijn.h"  // class binary_debruijn
-// demo-include "comb/binary-necklace.h"
+#include "comb/binary-necklace.h"
 
 #include "fxttypes.h"
 #include "fxtio.h"
