@@ -76,9 +76,20 @@ main(int argc, char **argv)
 // -------------------------
 
 /*
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
+
+time ./bin 39
+arg 1: 39 == n  [partitions of 1 into n powers of 1/2]  default=10
+arg 2: 1 == sq  [whether to print sums]  default=1
+ ct=1127987211
+4.50user 0.00system 0:04.50elapsed 100%CPU
+ ==> 1127987211/4.50 == 250,663,824 per second
+
+
 Timing: (AMD Phenom II X4 945 3000MHz)
 
- time ./bin 39
+time ./bin 39
 arg 1: 39 == n  [partitions of 1 into n powers of 1/2]  default=10
 arg 2: 1 == sq  [whether to print sums]  default=1
  ct=1127987211
