@@ -83,22 +83,15 @@ main(int argc, char **argv)
 // -------------------------
 
 /*
-Timing:
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
 
 with BINARY_NECKLACE_MAX_ARRAY_LEN defined:
  time ./bin 34
 arg 1: 34 == n  [Number of bits]  default=8
- n = 34:    # pre-necklaces = 1043325198
-./bin 34  8.07s user 0.00s system 99% cpu 8.069 total
- ==> 1043325198/8.07 == 129,284,411 per second
-
-with pointers:
- time ./bin 34
-arg 1: 34 == n  [Number of bits]  default=8
- n = 34:    # pre-necklaces = 1043325198
-./bin 34  8.14s user 0.00s system 100% cpu 8.139 total
- ==> 1043325198/8.14 == 128,172,628 per second
-
+  # pre-necklaces = 1043325198
+2.22user 0.00system 0:02.22elapsed 100%CPU
+ ==> 1043325198/2.22 == 469,966,305 per second
 */
 
 /*
