@@ -9,7 +9,7 @@
 #include "jjassert.h"
 
 
-//% Generating all combinations in lexicographic order.
+//% Combinations (n choose k) in lexicographic order.
 
 //#define TIMING  // uncomment to disable printing
 
@@ -31,6 +31,7 @@ main(int argc, char **argv)
 
     ulong ct = 0;
 #if defined TIMING
+    if ( rq )  cout << "backwards:\n";
     if ( 0==rq )  do  { ++ct; }  while ( k!=C.next() );
     else          do  { ++ct; }  while ( k!=C.prev() );
 
@@ -60,25 +61,51 @@ main(int argc, char **argv)
 
 
 /*
-Timing:
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
 
-stem 99% cpu 1.128 total
-15:18:21 jj@shuttle:~/work/fxt/ %  time ./bin 32 20
+time ./bin 32 20 0
 arg 1: 32 == n  [Combinations (n choose k) in lexicographic order:  n>0]  default=7
 arg 2: 20 == k  [ 0 < k <= n]  default=4
 arg 3: 0 == rq  [Whether to reverse order]  default=0
  ct = 225792840
-./bin 32 20  2.17s user 0.00s system 99% cpu 2.172 total
- ==> 225792840/2.17 == 104,052,000 per second
+0.71user 0.00system 0:00.71elapsed 99%CPU
+ ==> 225792840/0.71 == 318,018,084 per second
 
-%  time ./bin 32 12
+ time ./bin 32 12 0
 arg 1: 32 == n  [Combinations (n choose k) in lexicographic order:  n>0]  default=7
 arg 2: 12 == k  [ 0 < k <= n]  default=4
 arg 3: 0 == rq  [Whether to reverse order]  default=0
  ct = 225792840
-./bin 32 12  1.36s user 0.00s system 99% cpu 1.367 total
- ==> 225792840/1.36 == 166,024,147 per second
+0.50user 0.00system 0:00.50elapsed 100%CPU
+ ==> 225792840/0.50 == 451,585,680 per second
 
+
+ time ./bin 32 20 1
+arg 1: 32 == n  [Combinations (n choose k) in lexicographic order:  n>0]  default=7
+arg 2: 20 == k  [ 0 < k <= n]  default=4
+arg 3: 1 == rq  [Whether to reverse order]  default=0
+backwards:
+ ct = 225792840
+0.85user 0.00system 0:00.85elapsed 100%CPU
+ ==> 225792840/0.85 == 265,638,635 per second
+
+  time ./bin 32 12 1
+arg 1: 32 == n  [Combinations (n choose k) in lexicographic order:  n>0]  default=7
+arg 2: 12 == k  [ 0 < k <= n]  default=4
+arg 3: 1 == rq  [Whether to reverse order]  default=0
+backwards:
+ ct = 225792840
+0.59user 0.00system 0:00.59elapsed 100%CPU
+ ==> 225792840/0.59 == 382,699,728 per second
+
+*/
+
+/*
+BENCHARGS=32 20 0
+BENCHARGS=32 12 0
+BENCHARGS=32 20 1
+BENCHARGS=32 12 1
 */
 
 /// Emacs:
