@@ -38,10 +38,10 @@ main(int argc, char **argv)
     composition_nz P(n);
     ulong ct = 0;
 
-#ifdef TIMING
+#if defined TIMING
     bool bq = 0;
     NXARG(bq, "With benchmark: whether to generate in backward order");
-#ifdef COMPOSITION_NZ_FIXARRAYS
+#if defined COMPOSITION_NZ_FIXARRAYS
     cout << "COMPOSITION_NZ_FIXARRAYS defined." << endl;
 #endif
     if ( ! bq )
