@@ -31,7 +31,7 @@ main(int argc, char **argv)
     NXARG(n, "Total of n elements.");
 
     ulong k = 3;
-    NXARG(k, "Permutations of k elements (1<=k<=n).");
+    NXARG(k, "Prefix length: Permutations of k elements (1<=k<=n).");
     if ( k<1 )  k = 1;
     if ( k>n )  k = n;
 
@@ -61,15 +61,15 @@ main(int argc, char **argv)
         cout << setw(4) << ct << ":";
         ++ct;
 
-        print_perm("    ", x, k, dfz);
-        print_perm("", x+k, n-k, dfz);
+        print_perm("    ", x, k, dfz);  // prefix
+        print_perm("", x+k, n-k, dfz);  // rest
 
         P.get_swap(sw1, sw2);
         cout << "  (" << sw1 << ", " << sw2 << ")";
 
         print_mixedradix("    ", a, n-1, dfz);
 
-        print_perm("    ", ix, n, dfz);
+        print_perm("    ", ix, n, dfz);  // inverse permutation
 
         cout << endl;
 
