@@ -32,7 +32,7 @@ main(int argc, char **argv)
     jjassert( n >= 1 );
 
     ulong k = 3;
-    NXARG(k, "Permutations of k elements, (1<=k<=n)");
+    NXARG(k, "Prefix length: permutations of k elements, (1<=k<=n)");
     jjassert( k <= n );
 
     kperm_lex P(n);
@@ -65,7 +65,7 @@ main(int argc, char **argv)
 //        perm2ffact(x, n, F);  // first k k positions same as in d[]
 //        print_vec("  ", F, n-1, true);
 
-        print_perm("    ", ix, n, dfz);
+        print_perm("    ", ix, n, dfz);  // inverse permutation
 
         cout << endl;
 
@@ -87,73 +87,50 @@ main(int argc, char **argv)
 
 
 /*
-Timing:
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
 
- time ./bin 12 12
+time ./bin 12 12
 arg 1: 12 == n  [Total of n elements, n>=1]  default=5
 arg 2: 12 == k  [Permutations of k elements, (1<=k<=n)]  default=3
-  ct=479001600
-./bin 12 12  16.12s user 0.01s system 100% cpu 16.127 total
- ==> 479001600/16.12 == 29,714,739 per second
+ ct=479001600
+6.19user 0.00system 0:06.19elapsed 99%CPU
+ ==> 479001600/6.19 == 77,383,134 per second
 
-
- time ./bin 12 11
+time ./bin 12 11
 arg 1: 12 == n  [Total of n elements, n>=1]  default=5
 arg 2: 11 == k  [Permutations of k elements, (1<=k<=n)]  default=3
-  ct=479001600
-./bin 12 11  15.58s user 0.00s system 99% cpu 15.600 total
- ==> 479001600/15.58 == 30,744,646 per second
+ ct=479001600
+5.92user 0.00system 0:05.92elapsed 100%CPU
+ ==> 479001600/5.92 == 80,912,432 per second
 
- time ./bin 12 10
+time ./bin 12 10
 arg 1: 12 == n  [Total of n elements, n>=1]  default=5
 arg 2: 10 == k  [Permutations of k elements, (1<=k<=n)]  default=3
-  ct=239500800
-./bin 12 10  6.41s user 0.01s system 99% cpu 6.426 total
- ==> 239500800/6.41 == 37,363,619 per second
+ ct=239500800
+2.89user 0.00system 0:02.89elapsed 100%CPU
+ ==> 239500800/2.89 == 82,872,249 per second
 
- time ./bin 24 6
+time ./bin 24 6
 arg 1: 24 == n  [Total of n elements, n>=1]  default=5
 arg 2: 6 == k  [Permutations of k elements, (1<=k<=n)]  default=3
-  ct=96909120
-./bin 24 6  1.48s user 0.00s system 99% cpu 1.478 total
- ==> 96909120/1.48 == 65,479,135 per second
+ ct=96909120
+0.57user 0.00system 0:00.57elapsed 100%CPU
+ ==> 96909120/0.57 == 170,016,000 per second
 
- time ./bin 52 5
+time ./bin 52 5
 arg 1: 52 == n  [Total of n elements, n>=1]  default=5
 arg 2: 5 == k  [Permutations of k elements, (1<=k<=n)]  default=3
-  ct=311875200
-./bin 52 5  4.14s user 0.00s system 100% cpu 4.147 total
- ==> 311875200/4.14 == 75,332,173 per second
+ ct=311875200
+1.48user 0.00system 0:01.48elapsed 99%CPU
+ ==> 311875200/1.48 == 210,726,486 per second
 
- time ./bin 100 4
+time ./bin 100 4
 arg 1: 100 == n  [Total of n elements, n>=1]  default=5
 arg 2: 4 == k  [Permutations of k elements, (1<=k<=n)]  default=3
-  ct=94109400
-./bin 100 4  1.19s user 0.00s system 100% cpu 1.195 total
- ==> 94109400/1.19 == 79,083,529 per second
-*/
-
-/*
-Timing: (AMD Phenom II X4 945 3000MHz)
-
- time ./bin 12 12
-arg 1: 12 == n  [Total of n elements, n>=1]  default=5
-arg 2: 12 == k  [Permutations of k elements, (1<=k<=n)]  default=3
- ct=479001600
-./bin 12 12  12.31s user 0.00s system 99% cpu 12.316 total
- ==> 479001600/12.31 == 38,911,584 per second
-*/
-
-/*
-Timing: (AMD Phenom II X4 945 3000MHz)
-
- time ./bin 12 12
-arg 1: 12 == n  [Total of n elements, n>=1]  default=5
-arg 2: 12 == k  [Permutations of k elements, (1<=k<=n)]  default=3
- ct=479001600
-./bin 12 12  6.20s user 0.00s system 99% cpu 6.207 total
- ==> 479001600/6.20 == 77,258,322 per second
-
+ ct=94109400
+0.42user 0.00system 0:00.42elapsed 99%CPU
+ ==> 94109400/0.42 == 224,070,000 per second
 */
 
 
