@@ -93,6 +93,85 @@ main(int argc, char **argv)
 
 
 /*
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
+
+time ./bin 42 2 0
+forward:
+ ct=701408733
+./bin 42 2 0 2.62s user 0.00s system 99% cpu 2.62s total
+ ==> 701408733/2.62 == 267.713256 [M per second];  1/rate == 13.82 [cycles]
+
+time ./bin 42 2 1
+backward:
+ ct=701408733
+./bin 42 2 1 2.90s user 0.00s system 99% cpu 2.90s total
+ ==> 701408733/2.90 == 241.86508 [M per second];  1/rate == 15.29 [cycles]
+
+time ./bin 29 3 0
+forward:
+ ct=715827883
+./bin 29 3 0 2.30s user 0.00s system 99% cpu 2.30s total
+ ==> 715827883/2.30 == 311.229514 [M per second];  1/rate == 11.88 [cycles]
+
+time ./bin 29 3 1
+backward:
+ ct=715827883
+./bin 29 3 1 2.42s user 0.00s system 99% cpu 2.42s total
+ ==> 715827883/2.42 == 295.796645 [M per second];  1/rate == 12.5 [cycles]
+
+time ./bin 24 4 0
+forward:
+ ct=727060321
+./bin 24 4 0 2.17s user 0.00s system 99% cpu 2.17s total
+ ==> 727060321/2.17 == 335.050839 [M per second];  1/rate == 11.04 [cycles]
+
+time ./bin 24 4 1
+backward:
+ ct=727060321
+./bin 24 4 1 2.26s user 0.00s system 99% cpu 2.26s total
+ ==> 727060321/2.26 == 321.708106 [M per second];  1/rate == 11.5 [cycles]
+
+time ./bin 18 8 0
+forward:
+ ct=2245983825
+./bin 18 8 0 6.13s user 0.00s system 99% cpu 6.13s total
+ ==> 2245983825/6.13 == 366.392141 [M per second];  1/rate == 10.09 [cycles]
+
+time ./bin 18 8 1
+backward:
+ ct=2245983825
+./bin 18 8 1 6.36s user 0.00s system 99% cpu 6.36s total
+ ==> 2245983825/6.36 == 353.14211 [M per second];  1/rate == 10.47 [cycles]
+
+time ./bin 17 0 0
+forward:
+ ct=997313824
+./bin 17 0 0 2.46s user 0.00s system 99% cpu 2.46s total
+ ==> 997313824/2.46 == 405.412123 [M per second];  1/rate == 9.12 [cycles]
+
+time ./bin 17 0 1
+backward:
+ ct=997313824
+./bin 17 0 1 2.50s user 0.00s system 99% cpu 2.51s total
+ ==> 997313824/2.50 == 398.925529 [M per second];  1/rate == 9.27 [cycles]
+
+time ./bin 17 1 0
+forward:
+ ct=997313824
+./bin 17 1 0 3.40s user 0.00s system 99% cpu 3.41s total
+ ==> 997313824/3.40 == 293.327595 [M per second];  1/rate == 12.61 [cycles]
+
+time ./bin 17 1 1
+backward:
+ ct=997313824
+./bin 17 1 1 3.62s user 0.00s system 99% cpu 3.62s total
+ ==> 997313824/3.62 == 275.501056 [M per second];  1/rate == 13.43 [cycles]
+
+*/
+
+/*
+
 Timing: (AMD Phenom II X4 945 3000MHz)
 
 ----- args=42 2 0 ## binary is worst case (Fibonacci Gray code)
