@@ -1,5 +1,5 @@
 
-#include "comb/mixedradix-sod-lex.h"
+#include "comb/mixedradix-fixed-content.h"
 
 #include "nextarg.h"  // NXARG()
 #include "fxttypes.h"
@@ -37,7 +37,7 @@ main(int argc, char **argv)
     // radix == 1 + multiplicity:
     for (ulong i=4;  i<(ulong)argc; ++i)  r[i-4] = strtoul(argv[i], nullptr, 10) + 1;
 
-    mixedradix_sod_lex M(n, rr, ( argc > 4 ? r : nullptr ) );
+    mixedradix_fixed_content M(n, rr, ( argc > 4 ? r : nullptr ) );
     jjassert( M.first(k) );
 //    M.print_nines("Nines: ");
 //    cout << endl;
