@@ -3,14 +3,18 @@
 
 #include "comb/comb-print.h"
 #include "fxtio.h"
+#include "jjassert.h"
 #include "fxttypes.h"
 
 #include <cstdlib>  // strtoul()
 
 
 
-//% All multiset permutations via prefix shifts ("cool-lex" order)
-//% Same as: all strings with fixed content.
+//% Multiset permutations via prefix shifts ("cool-lex" order).
+//% See
+//%  Aaron Williams: Loopless Generation of Multiset Permutations using
+//%  a Constant Number of Variables by Prefix Shifts,
+//%  ACM-SIAM Symposium on Discrete Algorithms (SODA09), (2009).
 
 
 //#define TIMING  // uncomment to disable printing
@@ -52,6 +56,11 @@ main(int argc, char **argv)
 
 #if !defined TIMING
     const ulong n = P.n_;
+    jjassert( n > 0 );
+#else
+#if defined MSET_PERM_PREF_OPT
+    cout << "MSET_PERM_PREF_OPT is defined\n";
+#endif
 #endif
 
     ulong ct = 0;
@@ -84,67 +93,72 @@ main(int argc, char **argv)
 // -------------------------
 
 /*
-Timing:
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
 
- ============ MSET_PERM_PREF_LEN #defined, O(1) update of prefix length:
+ ============ MSET_PERM_PREF_OPT #defined, O(1) update of prefix length:
 
 time ./bin 2 2 2 3 3 3
 args: multiplicities of elements
 multiplicities: ( 2, 2, 2, 3, 3, 3 )  k=6  n=15
-ct=756756000
-./bin 2 2 2 3 3 3  10.71s user 0.03s system 100% cpu 10.736 total
- ==> 756756000/10.71 == 70,658,823 per second
+MSET_PERM_PREF_OPT is defined
+ ct=756756000
+5.01user 0.00system 0:05.01elapsed 100%CPU
+ ==> 756756000/5.01 == 151,049,101 per second
 
 time ./bin 3 3 3 2 2 2 ## reordered
 args: multiplicities of elements
 multiplicities: ( 3, 3, 3, 2, 2, 2 )  k=6  n=15
-ct=756756000
-./bin 3 3 3 2 2 2  10.94s user 0.02s system 100% cpu 10.967 total
- ==> 756756000/10.94 == 69,173,308 per second
+MSET_PERM_PREF_OPT is defined
+ ct=756756000
+5.03user 0.00system 0:05.03elapsed 100%CPU
+ ==> 756756000/5.03 == 150,448,508 per second
 
 time  ./bin 1 1 1 1 1 1 1 1 1 1 1 1  ## permutations of 12
 args: multiplicities of elements
 multiplicities: ( 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1 )  k=12  n=12
-ct=479001600
-./bin 1 1 1 1 1 1 1 1 1 1 1 1  6.71s user 0.02s system 100% cpu 6.730 total
- ==> 479001600/6.71 == 71,386,229 per second
+MSET_PERM_PREF_OPT is defined
+ ct=479001600
+3.15user 0.00system 0:03.15elapsed 100%CPU
+ ==> 479001600/3.15 == 152,064,000 per second
 
 time  ./bin 15 15  ## combinations (30 choose 15)
 args: multiplicities of elements
 multiplicities: ( 15, 15 )  k=2  n=30
-ct=155117520
-./bin 15 15  2.50s user 0.00s system 99% cpu 2.505 total
- ==> 155117520/2.50 == 62,047,008 per second
+MSET_PERM_PREF_OPT is defined
+ ct=155117520
+1.03user 0.00system 0:01.03elapsed 99%CPU
+ ==> 155117520/1.03 == 150,599,533 per second
 
-
- ============ MSET_PERM_PREF_LEN not #defined:
+ ============ MSET_PERM_PREF_OPT not #defined:
 
 time ./bin 2 2 2 3 3 3
+args: multiplicities of elements
 multiplicities: ( 2, 2, 2, 3, 3, 3 )  k=6  n=15
-ct=756756000
-./bin 2 2 2 3 3 3  11.97s user 0.01s system 99% cpu 11.977 total
- ==> 756756000/11.97 == 63,221,052 per second
+ ct=756756000
+4.07user 0.00system 0:04.07elapsed 100%CPU
+ ==> 756756000/4.07 == 185,935,135 per second
 
- time ./bin 3 3 3 2 2 2 ## reordered
+time ./bin 3 3 3 2 2 2 ## reordered
 args: multiplicities of elements
 multiplicities: ( 3, 3, 3, 2, 2, 2 )  k=6  n=15
-ct=756756000
-./bin 3 3 3 2 2 2  12.22s user 0.00s system 99% cpu 12.226 total
- ==> 756756000/12.22 == 61,927,659 per second
+ ct=756756000
+4.03user 0.00system 0:04.06elapsed 99%CPU
+ ==> 756756000/4.03 == 189,189,000 per second
 
 time  ./bin 1 1 1 1 1 1 1 1 1 1 1 1  ## permutations of 12
 args: multiplicities of elements
 multiplicities: ( 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1 )  k=12  n=12
-ct=479001600
-./bin 1 1 1 1 1 1 1 1 1 1 1 1  7.02s user 0.02s system 99% cpu 7.042 total
- ==> 479001600/7.02 == 68,233,846 per second
+ ct=479001600
+2.40user 0.00system 0:02.40elapsed 99%CPU
+ ==> 479001600/2.40 == 199,584,000 per second
 
 time  ./bin 15 15  ## combinations (30 choose 15)
 args: multiplicities of elements
 multiplicities: ( 15, 15 )  k=2  n=30
-ct=155117520
-./bin 15 15  3.35s user 0.00s system 99% cpu 3.357 total
- ==> 155117520/3.35 == 46,303,737 per second
+ ct=155117520
+0.86user 0.00system 0:00.86elapsed 99%CPU
+ ==> 155117520/0.86 == 180,369,209 per second
 */
 
 /*
