@@ -97,15 +97,15 @@ main(int argc, char **argv)
 // -------------------------
 
 /*
-Timing:
+Timing: Timing: (Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz)
+GCC 12.2.0
 
- time ./bin 32 2
-arg 1: 32 == n  [Length of necklaces (n>=1)]  default=6
+time ./bin 32 2
+arg 1: 32 == n  [Length of necklaces (n>=1)]  default=7
 arg 2: 2 == k  [Number of different beads (k>=2)]  default=2
-Generated 277737797 (32, 2) pre-necklaces.
-Generated 134219796 necklaces and 134215680 Lyndon words.
-./bin 32  11.67s user 0.06s system 99% cpu 11.733 total
- ==> 277737797/11.67 == 23,799,297 pre-necklaces per second
+ nct=134219796
+2.37user 0.00system 0:02.37elapsed 100%CPU
+ ==> 277737797/2.37 == 117,188,943 pre-necklaces per second
 
 */
 
