@@ -106,8 +106,18 @@ main(int argc, char **argv)
 // -------------------------
 
 /*
-Timing: (AMD Phenom II X4 945 3000MHz)
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
 
+time ./bin 19
+arg 1: 19 == n  [number of non-root nodes]  default=5
+ ct=1767263190
+3.26user 0.00system 0:03.27elapsed 99%CPU
+ ==> 1767263190/3.26 == 542,105,273 per second
+
+
+
+Timing: (AMD Phenom II X4 945 3000MHz)
 GCC 4.9.1:
 
  time ./bin 19
