@@ -67,6 +67,18 @@ main(int argc, char **argv)
 // -------------------------
 
 /*
+ Timing: (Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz)
+
+GCC 12.2.0
+
+time ./bin 170
+arg 1: 170 == n  [partitions of n]  default=13
+ ct=1270747344
+3.62user 0.00system 0:03.63elapsed 100%CPU (0avgtext+0avgdata 3444maxresident)k
+ ==> 1270747344/3.62 == 351,035,177 per second
+
+
+
 Timing: (AMD Phenom II X4 945 3000MHz)
 
 GCC 4.8.0:
