@@ -47,6 +47,12 @@ main(int argc, char **argv)
     long P0[3] = { 0, 0, 0 };
 #endif
 
+#if defined TIMING
+#if defined PEANO_NDIM_USE_CALC_DIR
+    cout << "PEANO_NDIM_USE_CALC_DIR is defined.\n";
+#endif
+#endif
+
     ulong ct = 1;  // point zero is first
     ulong coord_idx = 0;
     long dir = 0;
@@ -65,13 +71,14 @@ main(int argc, char **argv)
         cout << " " << (dir<0?'-':'+');
 //        cout << " " << (Peano.MR.dir()<0?'-':'+');
         Peano.MR.print("    ", true );
+//        cout << "  MR.dir = " << Peano.MR.dir();
         cout << endl;
 #endif  // TIMING
 
 #if defined DO_TEST
 
         const long * P = Peano.point();
-        const long x = P[0], y = P[1], z = P[2];
+        const ulong x = (ulong)P[0], y = (ulong)P[1], z = (ulong)P[2];
         jjassert( ! Arr.is_off( x, y, z ) );
         const ulong act = Arr[x][y][z];
         if ( 0 != act )  cout << " :: act = " << act << endl;
@@ -97,38 +104,35 @@ main(int argc, char **argv)
 
 
 /*
-Timing: (Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz)
+Timing: Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
+GCC 12.2.0
 
-GCC 8.30
+time ./bin 3 6
+arg 1: 3 == nd  [Number of dimensions]  default=2
+arg 2: 6 == it  [Iterate]  default=2
+ edge_length = 730
+ num_points = 387420489
+PEANO_NDIM_USE_CALC_DIR is defined.
+ ct=387420489
+2.16user 0.00system 0:02.16elapsed 100%CPU
+==> 387420489 / 2.16 == 179,361,337 points per second
 
-
-// with j_mod_nd[]:
 time ./bin 3 6
 arg 1: 3 == nd  [Number of dimensions]  default=2
 arg 2: 6 == it  [Iterate]  default=2
  edge_length = 730
  num_points = 387420489
  ct=387420489
-./bin 3 6  3.38s user 0.00s system 99% cpu 3.378 total
-==> 387420489 / 3.38 == 114,621,446 points per second
+3.12user 0.00system 0:03.12elapsed 100%CPU
+==> 387420489 / 3.12 == 124,173,233 points per second
 
 
-// without j_mod_nd[]:
-time ./bin 3 6
-arg 1: 3 == nd  [Number of dimensions]  default=2
-arg 2: 6 == it  [Iterate]  default=2
- edge_length = 730
- num_points = 387420489
- ct=387420489
-./bin 3 6  6.23s user 0.00s system 99% cpu 6.233 total
-==> 387420489 / 6.23 == 62,186,274 points per second
-
 
 cf. class mixedradix_gray:
 time ./bin 20 3
  ct=3486784401
-./bin 20 3  5.25s user 0.00s system 99% cpu 5.254 total
- ==> 3486784401 / 5.25 == 664,149,409 numbers per second
+7.09user 0.00system 0:07.09elapsed 100%CPU
+ ==> 3486784401 / 7.09 == 491,789,055 numbers per second
 
 */
 
