@@ -1,3 +1,4 @@
+#include "jjassert.h"
 
 #include "comb/perm-trotter.h"
 
@@ -105,6 +106,7 @@ PERM_TROTTER_OPT is defined.
 forward:
 ct=6227020800
 ./bin 13 0  15.00s user 0.00s system 99% cpu 14.996 total
+ ==> 6227020800 / 15.00 == 415,134,720 per second
 
 
 time ./bin 13 1
@@ -114,6 +116,7 @@ PERM_TROTTER_OPT is defined.
 backward:
 ct=6227020800
 ./bin 13 1  14.76s user 0.00s system 99% cpu 14.758 total
+ ==> 6227020800 / 14.76 == 421,884,878 per second
 
 
 time ./bin 13 0
@@ -122,6 +125,7 @@ arg 2: 0 == bq  [Whether to go backwards.]  default=0
 forward:
 ct=6227020800
 ./bin 13 0  25.89s user 0.00s system 99% cpu 25.897 total
+ ==> 6227020800 / 25.89 == 240,518,377 per second
 
 time ./bin 13 1
 arg 1: 13 == n  [Permutations of n elements.]  default=4
@@ -129,45 +133,7 @@ arg 2: 1 == bq  [Whether to go backwards.]  default=0
 backward:
 ct=6227020800
 ./bin 13 1  27.19s user 0.00s system 99% cpu 27.192 total
-
-*/
-
-/*
-Timing: (Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz)
-GCC 8.3.0
-
-time ./bin 13 0
-arg 1: 13 == n  [Permutations of n elements.]  default=4
-arg 2: 0 == bq  [Whether to go backwards.]  default=0
-PERM_TROTTER_OPT is defined.
-forward:
-ct=6227020800
-./bin 13 0  14.66s user 0.00s system 99% cpu 14.658 total
- ==> 6227020800 / 14.66 == 424,762,673 per second
-
-time ./bin 13 1
-arg 1: 13 == n  [Permutations of n elements.]  default=4
-arg 2: 1 == bq  [Whether to go backwards.]  default=0
-PERM_TROTTER_OPT is defined.
-backward:
-ct=6227020800
-./bin 13 1  14.70s user 0.00s system 99% cpu 14.703 total
- ==> 6227020800 / 14.70 == 423,606,857 per second
-
-
-time ./bin 13 0
-arg 1: 13 == n  [Permutations of n elements.]  default=4
-arg 2: 0 == bq  [Whether to go backwards.]  default=0
-forward:
-ct=6227020800
-./bin 13 0  26.82s user 0.00s system 99% cpu 26.821 total
-
-time ./bin 13 1
-arg 1: 13 == n  [Permutations of n elements.]  default=4
-arg 2: 1 == bq  [Whether to go backwards.]  default=0
-backward:
-ct=6227020800
-./bin 13 1  28.45s user 0.00s system 99% cpu 28.458 total
+ ==> 6227020800 / 27.19  == 229,018,786 per second
 
 */
 
