@@ -29,8 +29,8 @@ main(int argc, char **argv)
 
     ulong ct = 0;
 
-#ifdef TIMING
-#ifdef SCORE_SEQUENCE_FIXARRAYS
+#if defined TIMING
+#if defined SCORE_SEQUENCE_FIXARRAYS
     cout << "SCORE_SEQUENCE_FIXARRAYS is defined" << endl;
 #endif
     S.first();
