@@ -7,7 +7,7 @@
 //#include "aux0/rand-idx.h"
 //#include "perm/permrand.h"
 
-#include "perm/permq.h"
+#include "perm/permq.h"  // perm_is_valid(), perm_is_derangement()
 #include "comb/comb-print.h"
 
 #include "fxtio.h"
@@ -48,8 +48,8 @@ main(int argc, char **argv)
         print_cycles("    ", f, n);
         cout << endl;
 #endif  // TIMING
-//        jjassert( is_valid_permutation(f, n) );
-        jjassert( is_derangement(f, n) );
+//        jjassert( perm_is_valid(f, n) );
+        jjassert( perm_is_derangement(f, n) );
     }
 
     delete [] f;
