@@ -8,7 +8,7 @@
 
 #include "perm/printcycles.h"
 #include "comb/comb-print.h"
-#include "perm/permq.h"
+#include "perm/permq.h"  // perm_genus()
 
 #include "comb/fact2perm.h"
 
@@ -159,39 +159,52 @@ main(int argc, char **argv)
     {
     case 0:
         cout << "All permutations:" << endl;
-        perm = new perm1_prefix_cond(n, cond_0, visit);  break;
+        perm = new perm1_prefix_cond(n, cond_0);  break;
     case 1:
         cout << "Involutions (self-inverse permutations):" << endl;
-        perm = new perm1_prefix_cond(n, cond_inv, visit);  break;
+        perm = new perm1_prefix_cond(n, cond_inv);  break;
     case 2:
         cout << "Up-down permutations:" << endl;
-        perm = new perm1_prefix_cond(n, cond_updown, visit);  break;
+        perm = new perm1_prefix_cond(n, cond_updown);  break;
     case 3:
         cout << "Connected (indecomposable) permutations:" << endl;
-        perm = new perm1_prefix_cond(n, cond_indecomp, visit);  break;
+        perm = new perm1_prefix_cond(n, cond_indecomp);  break;
     case 4:
         cout << "Derangements:" << endl;
-        perm = new perm1_prefix_cond(n, cond_derange, visit);  break;
+        perm = new perm1_prefix_cond(n, cond_derange);  break;
     case 5:
         cout << "No [x,x+1]:" << endl;
-        perm = new perm1_prefix_cond(n, cond_xx1, visit);  break;
+        perm = new perm1_prefix_cond(n, cond_xx1);  break;
 
     case 6:
         cnd[0] = 0;
         cout << "Non-derangements (at least one fixed point):" << endl;
-        perm = new perm1_prefix_cond(n, cond_non_derange, visit);  break;
+        perm = new perm1_prefix_cond(n, cond_non_derange);  break;
 
 //    case 7:
 //        cout << "Playground:" << endl;
-//        perm = new perm1_prefix_cond(n, cond_dist_set, visit);  break;
+//        perm = new perm1_prefix_cond(n, cond_dist_set);  break;
 
     default:
         cout << "Error!" << endl;
         return 1;
     }
 
-    ulong ct = perm->all();
-
+    ulong ct = 0;
+    if ( perm->first() )
+    {
+#if ! defined TIMING
+        const ulong * x = perm->data1();
+#endif
+        do
+        {
+            ++ct;
+#if ! defined TIMING
+            visit( x, n, ct );
+#endif
+        }
+        while ( perm->next() );
+    }
 
     for (ulong j=0; j<n; ++j)  cout << stats[j] << ", ";
     cout << endl;
