@@ -11,7 +11,7 @@
 #include "nextarg.h"  // NXARG()
 
 //% OEIS sequence A309807:
-//% Number of permutations sigma of [n] such that sigma(k)/k > sigma(k+1)/(k+1) for 1 <= k <= n-1.
+//% Number of permutations sigma of [n] such that p(k)/k > p(k+1)/(k+1) for 1 <= k <= n-1.
 
 
 // Cf. comb/mixedradix-prefix-cond-demo.cc for mixed radix numbers with restricted prefixes.
@@ -59,7 +59,7 @@ main(int argc, char **argv)
     {
     case 1:
         cout << "A309807:" << endl;
-        perm = new perm1_prefix_cond(n, cond_A309807, visit);
+        perm = new perm1_prefix_cond(n, cond_A309807);
         break;
 //    case 2:
 //        cout << "?? permutations:" << endl;
@@ -69,7 +69,22 @@ main(int argc, char **argv)
         return 1;
     }
 
-    ulong ct = perm->all();
+    ulong ct = 0;
+    if ( perm->first() )
+    {
+#if ! defined TIMING
+        const ulong * x = perm->data1();
+#endif
+        do
+        {
+            ++ct;
+#if ! defined TIMING
+            visit( x, n, ct );
+#endif
+        }
+        while ( perm->next() );
+    }
+    cout << " ct=" << ct << endl;
     cout << " ct=" << ct << endl;
 
     delete perm;
