@@ -1,12 +1,13 @@
 #if !defined  HAVE_PERM_STAR_INV_H__
 #define       HAVE_PERM_STAR_INV_H__
 // This file is part of the FXT library.
-// Copyright (C) 2023 Joerg Arndt
+// Copyright (C) 2023, 2024 Joerg Arndt
 // License: GNU General Public License version 3 or later,
 // see the file COPYING.txt in the main directory.
 
 #include "comb/perm-rev.h"
-#include "fxtio.h"
+#include "comb/comb-print.h"
+#include "fxttypes.h"
 
 
 class perm_star_inv
