@@ -11,7 +11,7 @@
 #include "fxttypes.h"
 
 
-//#define PERM_TROTTER_OPT  // default on
+#define PERM_TROTTER_OPT  // default on
 // GCC 4.5.0: massive speedup, about a factor of 2
 // GCC 4.8.0: speedup (but big overall regression against GCC 4.5.0)
 // GCC 8.3.0: massive speedup, about a factor of 2
@@ -19,8 +19,12 @@
 
 
 class perm_trotter
-// Gray code for permutations, Trotter/Johnson algorithm.
+// Gray code for permutations, Johnson/Steinhaus/Trotter algorithm.
 // Smallest element moves most often.
+//  Selmer M. Johnson: Generation of permutations by adjacent transposition,
+//  Mathematics of Computation, vol.~17, no.~83, pp.~282-285, (July-1963).
+//  H. F. Trotter: Algorithm 115: Perm,
+//  Communications of the ACM, vol.5, no.8, pp.434-435, (August-1962).
 {
 public:
     ulong n_;     // number of elements to permute
@@ -49,7 +53,6 @@ public:
 
         x_[0] = x_[n_+1] = 0;  // sentinel value minimal
         ++x_;  // nota bene
-
         first();
     }
 
